@@ -11,8 +11,6 @@
 /* This must include the futex call */
 #include <asm/unistd.h>
 
-#include ARCH_ATOMICS_C
-
 /* FIXME: Standby code in case no real unistd.h */
 #ifndef __NR_futex
 #ifdef __PPC
@@ -42,23 +40,11 @@ int futex_region(void *area, size_t size)
 void futex_init(struct futex *futx)
 {
 	futx->count = 1;
-	__commit();
+	__futex_commit();
 }
 
-/* Down and up operations */
-int futex_down(struct futex *futx)
+/* Down and up operations in kernel */
+int sys_futex(struct futex *futx, int op)
 {
-	if (__down(&futx->count))
-		return futex(futx, -1);
-	return 0;
-}
-
-/* If __up increments count from 0 -> 1, noone was waiting.
-   Otherwise, others might be, so enter kernel which sets to 1 and
-   wakes them up. */
-int futex_up(struct futex *futx)
-{
-	if (__up(&futx->count))
-		return futex(futx, 1);
-	return 0;
+	return futex(futx, op);
 }
